@@ -55,12 +55,16 @@
 
 #include "compile.h"
 
-int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, int referee, int append, csch_attrib_t **dsta_out)
+int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, const char *err3, int referee, int append, csch_attrib_t **dsta_out)
 {
 	csch_attrib_t *dsta = NULL;
 	const char *key = (dstkey == NULL ? srca->key : dstkey);
 	const char *sval, *dval;
 
+	if (err1 == NULL) err1 = "";
+	if (err2 == NULL) err2 = "";
+	if (err3 == NULL) err3 = "";
+
 	if (key[0] == '-') {
 		if (dsta_out != NULL) *dsta_out = NULL;
 		csch_attr_src_free(src);
@@ -111,7 +115,7 @@ int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attr
 					}
 					if (srca->prio == dsta->prio) {
 						if (!referee) /* it's okay if a group ref's referee had it - we are overwriting it from the group ref */
-							rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: attribute collision for '%s'\n", err1, err2, srca->key);
+							rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s %s: attribute collision for '%s'\n", err1, err2, err3, srca->key);
 						csch_attr_src_free(src);
 						return -1;
 					}
@@ -125,7 +129,7 @@ int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attr
 		if (append) {
 			if ((dsta != NULL) && (dval != NULL)) {
 				csch_attr_src_free(src);
-				rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: can not append to destination attribute '%s', it is a string not an array\n", err1, err2, key);
+				rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s %s: can not append to destination attribute '%s', it is a string not an array\n", err1, err2, err3, key);
 				return -1;
 			}
 			return csch_attrib_append_val(&dst->attr, srca->prio, key, srca, src);
@@ -150,7 +154,7 @@ static void compile_attribute_copy_srcs_front(csch_attrib_t *dst, const csch_att
 		dst->source.array[n] = rnd_strdup(srca->source.array[n]);
 }
 
-static int compile_attributes(csch_ahdr_t *dst, const csch_attribs_t *src, csch_cgrp_t *cgrp, const char *err1, const char *err2, int referee)
+static int compile_attributes(csch_ahdr_t *dst, const csch_attribs_t *src, csch_cgrp_t *cgrp, const char *err1, const char *err2, const char *err3, int referee)
 {
 	htsp_entry_t *e;
 	int res = 0, r1;
@@ -160,7 +164,7 @@ static int compile_attributes(csch_ahdr_t *dst, const csch_attribs_t *src, csch_
 		csch_source_arg_t *src = csch_attrib_src_ac(&cgrp->hdr, srca->key, "compile_attributes()");
 		csch_attrib_t *dsta;
 
-		r1 = csch_compile_attribute(dst, NULL, srca, src, err1, err2, referee, 0, &dsta);
+		r1 = csch_compile_attribute(dst, NULL, srca, src, err1, err2, err3, referee, 0, &dsta);
 
 		if ((r1 == 0) && (dsta != NULL))
 			compile_attribute_copy_srcs_front(dsta, srca);
@@ -214,7 +218,7 @@ static int compile_wire_net(csch_abstract_t *dst, int viewid, csch_hier_path_t *
 	csch_eng_free_namemod(&name_glob, &name_loc);
 
 	csch_compile_add_source(src, &net->hdr);
-	return compile_attributes(&net->hdr, &src->attr, src, "net", orig_name, 0);
+	return compile_attributes(&net->hdr, &src->attr, src, "net", orig_name, NULL, 0);
 }
 
 static csch_aport_t *compile_port(csch_abstract_t *dst, int viewid, csch_hier_path_t *hpath, const csch_sheet_t *sheet, csch_acomp_t *comp, csch_cgrp_t *t, int hier_down)
@@ -264,7 +268,7 @@ static csch_aport_t *compile_port(csch_abstract_t *dst, int viewid, csch_hier_pa
 	port->parent = comp;
 	csch_compile_add_source(t, &port->hdr);
 
-	compile_attributes(&port->hdr, &t->attr, t, "port", orig_name, 0);
+	compile_attributes(&port->hdr, &t->attr, t, "port", (comp == NULL ? "" : comp->name), orig_name, 0);
 
 	csch_eng_free_namemod(&name_glob, &name_loc);
 
@@ -291,9 +295,9 @@ static int compile_symbol_to_component(csch_abstract_t *dst, int viewid, csch_hi
 
 	csch_compile_add_source(src, &comp->hdr);
 
-	res |= compile_attributes(&comp->hdr, &src->attr, src, "component", orig_name, 0);
+	res |= compile_attributes(&comp->hdr, &src->attr, src, "component", orig_name, NULL, 0);
 	if ((src->hdr.type == CSCH_CTYPE_GRP_REF) && (src->data.ref.grp != NULL))
-		res |= compile_attributes(&comp->hdr, &src->data.ref.grp->attr, src->data.ref.grp, "component", orig_name, 1);
+		res |= compile_attributes(&comp->hdr, &src->data.ref.grp->attr, src->data.ref.grp, "component", orig_name, NULL, 1);
 
 	csch_eng_call((csch_project_t *)sheet->hidlib.project, viewid, hpath, CSCH_ENGHK_SYMBOL_JOINED_COMPONENT,
 		FGW_COBJ, src, FGW_AOBJ, comp, FGW_HPATH, hpath, FGW_INVALID);
@@ -903,6 +907,13 @@ static int cmp_comp_hdepth(const void *C1, const void *C2)
 	const csch_acomp_t **c1 = (const csch_acomp_t **)C1;
 	const csch_acomp_t **c2 = (const csch_acomp_t **)C2;
 
+	/* secondary key: if depths are the same, sort by aid for reproducible output
+	   (different libc implementations will behave differently if primary key
+	   is equal) */
+	if ((*c1)->hdepth == (*c2)->hdepth)
+		return ((*c1)->hdr.aid > (*c2)->hdr.aid) ? +1 : -1;
+
+	/* primary key: hdepth */
 	if ((*c1)->hdepth > (*c2)->hdepth) return 1;
 	return -1;
 }
