@@ -104,6 +104,12 @@ static csch_line_t *find_wire(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t
 	return ctx.res;
 }
 
+csch_line_t *csch_find_wire_at(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y, csch_chdr_t *ignore)
+{
+	return find_wire(sheet, x, y, ignore);
+}
+
+
 csch_cgrp_t *csch_wirenet_new_from(csch_sheet_t *sheet, const csch_cgrp_t *attr_src)
 {
 	csch_source_arg_t *src;
