@@ -144,8 +144,8 @@ static char *read_str(read_ctx_t *ctx)
 			ctx->lineno++;
 			return tmp.array;
 		}
-
-		gds_append(&tmp, c);
+		if (c != '\r')
+			gds_append(&tmp, c);
 	}
 }
 
@@ -355,7 +355,7 @@ static int place_text(read_ctx_t *ctx, csch_cgrp_t *parent, long x, long y, long
 			do_attr = 1;
 
 
-		if (do_attr && (parent != NULL)) {
+		if (do_attr && (parent != NULL) && (sep != NULL)) {
 			*sep = '\0';
 			sep++;
 			if (create_attr)
@@ -603,7 +603,10 @@ static int read_bus(read_ctx_t *ctx, csch_cgrp_t *parent)
 		return -1;
 	}
 	dbg_printf("bus at %ld;%ld %ld;%ld\n", x1, y1, x2, y2);
-	TODO("create bus, watch for rippers? or rather keep buses as purely graphical");
+	/* buses are purely graphical in geda and connections are made by other
+	   means - emulate that by drawing decoration lines */
+	csch_alien_mkline(&ctx->alien, parent, x1, y1, x2, y2, "bus");
+
 	READ_NL(ctx);
 	return 0;
 }
@@ -917,6 +920,17 @@ static void last_comp_move_fields(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t
 	csch_cnc_remove(ctx->sheet, &src->hdr);
 }
 
+static void sym_error(read_ctx_t *ctx, const char *msg)
+{
+	double x = (double)ctx->last_comp->x, y = (double)ctx->last_comp->y;
+	csch_text_t *text;
+
+	text = (csch_text_t *)csch_alien_mktext(&ctx->alien, ctx->last_comp, x, y, "sym-error");
+	text->text = rnd_strdup(msg);
+	text = (csch_text_t *)csch_alien_mktext(&ctx->alien, ctx->last_comp, x, y-DEF_TERM_GRID, "sym-error");
+	text->text = rnd_strdup(ctx->last_comp_name);
+}
+
 static void flush_last_comp(read_ctx_t *ctx)
 {
 	if (!ctx->no_ext_sym && (ctx->last_comp != NULL) && !ctx->last_comp_embedded && (ctx->last_comp_name != NULL)) {
@@ -952,11 +966,15 @@ static void flush_last_comp(read_ctx_t *ctx)
 				}
 
 			}
-			else
+			else {
 				error(ctx, ("Failed to load library symbol called '%s'\n", ctx->last_comp_name));
+				sym_error(ctx, "!broken sym:");
+			}
 		}
-		else
+		else {
 			error(ctx, ("Can't find library symbol called '%s'\n", ctx->last_comp_name));
+			sym_error(ctx, "!sym not found:");
+		}
 
 	}
 
@@ -1260,18 +1278,16 @@ static csch_cgrp_t *load_sym(rnd_design_t *hidlib, const char *fn, csch_sheet_t
 
 	res = load_sym_(&ctx);
 
-	if (res == 0)
-		io_geda_postproc(&ctx);
-
 	fclose(ctx.f);
 
 	return res;
 }
 
-
+/* IO API function (load symbol from lib) */
 csch_cgrp_t *io_geda_load_grp(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet)
 {
 	read_ctx_t ctx = {0};
+	csch_cgrp_t *grp;
 
 	if (htip_get(&sheet->direct.id2obj, 1) != NULL) {
 		rnd_message(RND_MSG_ERROR, "Error loading '%s': there's already a group1 in destination sheet\n", fn);
@@ -1285,7 +1301,11 @@ csch_cgrp_t *io_geda_load_grp(FILE *f, const char *fn, const char *fmt, csch_she
 
 	alien_setup(&ctx);
 
-	return load_sym_(&ctx);
+	grp = load_sym_(&ctx);
+	if (io_geda_postproc(&ctx) != 0)
+		rnd_message(RND_MSG_ERROR, "io_geda: failed to postprocess newly loaded symbol\n");
+
+	return grp;
 }
 
 int io_geda_test_parse(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type)
