@@ -399,15 +399,16 @@ fgw_error_t csch_act_BufferSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 static const char csch_acts_BufferLoad[] = "BufferLoad([group|symbol|all, [filename], [fmt])";
-static const char csch_acth_BufferLoad[] = "Load content of buffer; if first arg is symbol, the first symbol group is saved, if sheet the whole buffer is saved as sheet\n";
+static const char csch_acth_BufferLoad[] = "Load content of buffer from file\n";
 fgw_error_t csch_act_BufferLoad(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int rv = -1, cmd = F_Sheet;
 	char *fn = NULL;
 	const char *fmt = "lihata";
 
-	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, BufferSave, cmd = fgw_keyword(&argv[1]));
-	RND_ACT_MAY_CONVARG(2, FGW_STR, BufferSave, fn = argv[2].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, BufferLoad, cmd = fgw_keyword(&argv[1]));
+	RND_ACT_MAY_CONVARG(2, FGW_STR, BufferLoad, fn = argv[2].val.str);
+	RND_ACT_MAY_CONVARG(3, FGW_STR, BufferLoad, fmt = argv[3].val.str);
 
 	if (fn == NULL) {
 		static char *default_file = NULL;
