@@ -26,5 +26,10 @@ void sch_rnd_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e);
 /*** calls useful in preview ***/
 void sch_rnd_draw_sheet(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller);
 
+/*** helpers ***/
+/* Set up sheet for rendering the text of a non-graphical sheet; sets size and
+   colors and grid */
+int sch_draw_setup_non_graphical(csch_sheet_t *sheet, long lines);
+
 
 #endif
